@@ -29,7 +29,7 @@
 /*      EPS_ERR_CODE lprWritePrintData  (buffer, bufferlen, sendlen             );      */
 /*      EPS_ERR_CODE lprGetStatus       (printer, status, ioStatus              );      */
 /*      EPS_ERR_CODE lprGetJobStatus    (pstInfo			                    );      */
-/*      EPS_ERR_CODE lprGetPMString     (printer, pString, bufSize              );      */
+/*      EPS_ERR_CODE lprGetInfo         (printer, pString, bufSize              );      */
 /*      EPS_ERR_CODE lprMechCommand     (printer, Command                       );      */
 /*                                                                                      */
 /*******************************************|********************************************/
@@ -153,11 +153,12 @@ EPS_ERR_CODE lprFindStart(
 
 		EPS_SOCKET*		sock,
 		const EPS_INT8*	address,
-		EPS_BOOL        multi
+		EPS_BOOL        multi,
+		const EPS_UINT8*  mac
 		
 ){
 	EPS_LOG_FUNCIN
-	EPS_RETURN( snmpFindStart(sock, address, multi) )
+	EPS_RETURN( snmpFindStart(sock, address, multi, mac) )
 }
 
 
@@ -625,7 +626,7 @@ EPS_ERR_CODE lprGetStatus(
 		EPS_RETURN( ret )
 	}
 
-	ret = snmp.GetStatus(sock, printer->location, pstInfo );
+	ret = snmp.GetStatus(sock, printer->location, snmp.egID, pstInfo );
 
 	if( !IS_VALID_DATA_SESSION ){
 		/* Another proceessing, or printing after endjob */
@@ -712,42 +713,13 @@ EPS_ERR_CODE lprGetJobStatus(
 	}
 	
 	/*** Get Printer status by SNMP                                                     */
-	EPS_RETURN( snmp.GetStatus( lprPrintJob->socStat, printer->location, pstInfo ) )
+	EPS_RETURN( snmp.GetStatus( lprPrintJob->socStat, printer->location, snmp.egID, pstInfo ) )
 }
 
 
 /*******************************************|********************************************/
 /*                                                                                      */
-/* Function name:     lprGetInkInfo()													*/
-/*                                                                                      */
-/* Arguments                                                                            */
-/* ---------                                                                            */
-/* Name:        Type:               Description:                                        */
-/* status		EPS_STATUS_INFO*	O: retrieve printer satus						    */
-/*                                                                                      */
-/* Return value:                                                                        */
-/*      EPS_ERR_NONE                    - Success                                       */
-/*      EPS_ERR_COMM_ERROR              - Communication Error                           */
-/*                                                                                      */ 
-/* Description:                                                                         */
-/*      Get Ink information.    				                                        */
-/*                                                                                      */
-/*******************************************|********************************************/
-EPS_ERR_CODE lprGetInkInfo(
-
-		EPS_STATUS_INFO*        pstInfo
-		
-){
-	EPS_PRINTER_INN*	printer = printJob.printer;
-
-	EPS_LOG_FUNCIN
-	EPS_RETURN( snmp.GetInkInfo(printer->location, pstInfo ) )
-}
-
-
-/*******************************************|********************************************/
-/*                                                                                      */
-/* Function name:     lprGetPMString()	        										*/
+/* Function name:     lprGetInfo()	                                                    */
 /*                                                                                      */
 /* Arguments                                                                            */
 /* ---------                                                                            */
@@ -767,16 +739,16 @@ EPS_ERR_CODE lprGetInkInfo(
 /*		PM String : pString                                                             */
 /*                                                                                      */
 /*******************************************|********************************************/
-EPS_ERR_CODE lprGetPMString(
+EPS_ERR_CODE lprGetInfo(
 								  
 		const EPS_PRINTER_INN*	printer, 
  		EPS_INT32               type,
-        EPS_UINT8*              pString,
+        EPS_UINT8**             pString,
 		EPS_INT32*              bufSize
 
 ){
 	EPS_LOG_FUNCIN
-	EPS_RETURN( snmp.GetPMString(printer, type, pString, bufSize) )
+	EPS_RETURN( snmp.InfoCommand(printer, type, pString, bufSize) )
 }
 
 
