@@ -1,7 +1,7 @@
 /*
  * Epson Inkjet Printer Driver (ESC/P-R) for Linux
  * Copyright (C) 2002-2005 AVASYS CORPORATION.
- * Copyright (C) Seiko Epson Corporation 2002-2013.
+ * Copyright (C) Seiko Epson Corporation 2002-2015.
  *
  *  This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,23 +34,12 @@
 /* added 22-04-2004 */
 #include <signal.h>
 
-#define NAME_MAX 41
+#include "libprtX.h"
 
 #define WIDTH_BYTES(bits) (((bits) + 31) / 32 * 4)
 
 #define PIPSLITE_WRAPPER_VERSION "* epson-escpr-wrapepr is a part of " PACKAGE_STRING
 
-
-typedef struct rtp_filter_option {
-	char model[NAME_MAX + 1];
-	char model_low[NAME_MAX + 1];
-	char ink[NAME_MAX + 1];
-	char media[NAME_MAX + 1];
-	char quality[NAME_MAX + 1];
-	char duplex[NAME_MAX + 1];
-	char inputslot[NAME_MAX + 1];
-} filter_option_t;
-
 /* Static functions */
 static int get_option_for_ppd (const char *, filter_option_t *);
 static int get_option_for_arg (const char *, filter_option_t *);
@@ -63,6 +52,7 @@ static void sigterm_handler (int sig);
 
 int cancel_flg;
 
+#define CUPS_READ_LINE	128
 #define DEBUG_PATH "/tmp/eps_wrapper.txt"
 
 #if (HAVE_DEBUG)
@@ -122,7 +112,6 @@ main (int argc, char *argv[])
 	while (flag) sleep (3);
 #endif /* USE_DEBUGGER */
 
-
 	cancel_flg = 0;
 	memset (&fopt, 0, sizeof (filter_option_t));
 	/* added 22-04-2004 */
@@ -160,7 +149,7 @@ main (int argc, char *argv[])
 	{
 		fd = 0;
 	}
-	 
+
 	if (get_option_for_arg (argv[5], &fopt))
 	{
 		fprintf (stderr, "Cannot read filter option. Cannot get option of PIPS.");
@@ -173,6 +162,7 @@ main (int argc, char *argv[])
 		debug_msg("PPD file not found, or PPD file is broken. Cannot get option of PIPS.");
 		return 1;
 	}
+
 	/* Print start */
 	ras = cupsRasterOpen (fd, CUPS_RASTER_READ);
 	if (ras == NULL)
@@ -183,17 +173,118 @@ main (int argc, char *argv[])
 	}
 
 	pfp = NULL;
-	while (cupsRasterReadHeader (ras, &header) && !cancel_flg)
+
+	int total_read = 0;
+	int total_read_cache = 0;
+	char *page_raw;      //2ページ分のバッファ
+	char *page_raw_cache;//2ページ分のキャッシュ
+
+	static BOOL first_fwrite = TRUE;
+	static BOOL cache_exist = FALSE;
+
+	int pageNum = 0;
+	while (1)
 	{
+		int ret;
+		ret = cupsRasterReadHeader (ras, &header);
+
+		if (ret == 0 || cancel_flg) //データをすべて読み終わった
+		{
+
+			if(cache_exist){//cacheがあればcacheを送信
+				int pageNum_cache = 2;
+				if(first_fwrite){//最初のfwriteだけ、ページ数を送信
+					fwrite (&pageNum_cache, 1, 1, pfp);
+					first_fwrite = FALSE;
+				}	
+
+				switch (pageNum){
+				case 1:
+					page_raw_cache[0] = 2;
+					page_raw_cache[total_read_cache/2 + 1] = 1;
+					break;
+				case 2:
+					page_raw_cache[0] = 99;
+					page_raw_cache[total_read_cache/2 + 1] = 99;
+					break;
+				default:
+					break;
+				}				
+
+				fwrite (page_raw_cache, total_read_cache + pageNum_cache, 1, pfp);				
+				cache_exist = FALSE;
+				total_read_cache = 0;
+			}
+			
+			//バッファを送信
+			switch (pageNum){
+			case 1:
+				page_raw[0] = 0;
+				break;
+			case 2:
+				page_raw[0] = 1;
+				page_raw[total_read/2 + 1] = 0;
+				break;
+			default:
+				break;
+			}
+
+			if(first_fwrite){//最初のfwriteだけ、ページ数を送信
+				fwrite (&pageNum, 1, 1, pfp);
+				first_fwrite = FALSE;
+			}	
+
+			fwrite (page_raw, total_read + pageNum, 1, pfp);
+
+
+			break;
+
+    	}else{
+			if(pageNum == 2){ //全部読み終わってないとき、２ページ分たまったら
+				total_read_cache = total_read;
+
+				if(cache_exist){//cacheがあればcacheを送信
+					int pageNum_cache = 2;
+					if(first_fwrite){//最初のfwriteだけ、ページ数を送信
+						fwrite (&pageNum_cache, 1, 1, pfp);
+						first_fwrite = FALSE;
+					}	
+
+					switch (pageNum){
+					case 1:
+						page_raw_cache[0] = 99;
+						page_raw_cache[total_read_cache/2 + 1] = 99;
+						break;
+					case 2:
+						page_raw_cache[0] = 2;
+						page_raw_cache[total_read_cache/2 + 1] = 99;
+						break;
+					default:
+						break;
+					}				
+
+					fwrite (page_raw_cache, total_read_cache + pageNum_cache, 1, pfp);				
+					cache_exist = FALSE;
+				}
+
+				//バッファをキャッシュへコピー
+				memcpy(page_raw_cache, page_raw, total_read_cache + pageNum + 1);
+				cache_exist = TRUE;
+			
+				total_read = 0;
+				pageNum = 0;
+	
+			}
+		}
+
 		int image_bytes;
 		char *image_raw;
-		int write_size = 0;
 
 		if (pfp == NULL)
 		{
 			char tmpbuf[256];
 
-			sprintf (tmpbuf, "%s/%s \"%s\" %d %d %d %s %s %s %s %s",
+			sprintf (tmpbuf, "%s/%s \"%s\" %d %d %d %s %s %s %s %s %s %s %s",
 				 CUPS_FILTER_PATH,
 				 CUPS_FILTER_NAME,
 				 fopt.model,
@@ -204,9 +295,13 @@ main (int argc, char *argv[])
 				 fopt.media,
 				 fopt.quality,
 				 fopt.duplex,
-				 fopt.inputslot);
-			
+				 fopt.inputslot,
+				 fopt.brightness,
+				 fopt.contrast,
+				 fopt.saturation);
+		
 			debug_msg("tmpbuf = [%s]\n", tmpbuf);
+
 			pfp = popen (tmpbuf, "w");
 
 			if (pfp == NULL)
@@ -215,34 +310,56 @@ main (int argc, char *argv[])
 				perror ("popen");
 				return 1;
 			}
+
+			// +1 .. left page num (2 / 1 / 0) , *2 .. 2page分のバッファ
+			image_bytes = (WIDTH_BYTES(header.cupsBytesPerLine * 8 ) * header.cupsHeight + 1) * 2; 
+			page_raw = (char *)calloc (sizeof (char), image_bytes);
+			page_raw_cache = (char *)calloc (sizeof (char), image_bytes);
+
 		}
 
-		image_bytes = WIDTH_BYTES(header.cupsBytesPerLine * 8);
+		image_bytes = WIDTH_BYTES(header.cupsBytesPerLine * 8 ) * CUPS_READ_LINE;
 		image_raw = (char *)calloc (sizeof (char), image_bytes);
 
-		for (i = 0; i < header.cupsHeight && !cancel_flg; i ++)
+
+		int left_lines = header.cupsHeight;	
+		while(!cancel_flg)		
 		{
-			if (!cupsRasterReadPixels (ras, (unsigned char*)image_raw, header.cupsBytesPerLine))
-			{
-				fprintf (stderr, "cupsRasterReadPixels");
-				debug_msg("cupsRasterReadPixels error");
-				return 1;
+			int cups_read_lines;
+			if(left_lines >= CUPS_READ_LINE){
+				cups_read_lines = CUPS_READ_LINE;
+			}else{
+				cups_read_lines = left_lines;
 			}
-			
-			write_size = fwrite (image_raw, image_bytes, 1, pfp);
-			if (write_size != 1)
-			{
-				perror ("fwrite");
-				debug_msg("fwrite error");
-				return 8;
+
+			int readpixels;
+			readpixels = cupsRasterReadPixels (ras, (unsigned char*)image_raw, header.cupsBytesPerLine * cups_read_lines);
+
+			if (readpixels == 0)
+			{	
+				// 1ページ分読み込み完了
+				break;
 			}
-		}
-		
-		free (image_raw);
-	}
+
+			memcpy((page_raw + pageNum +1) + total_read, image_raw, readpixels);
+			total_read += readpixels;
 	
+			left_lines -= CUPS_READ_LINE;
+
+		}//while (pixel data)
+
+			free (image_raw);
+
+			pageNum++;
+
+	}//while (cups header)
+
+	free (page_raw);
+	free (page_raw_cache);
+
 	pclose (pfp);
 	cupsRasterClose (ras);
+
 	return 0;
 }
 
@@ -298,9 +415,7 @@ get_option_for_ppd (const char *printer, filter_option_t *filter_opt_p)
 
 			if (!opt)return 1;	
 		}
-			
-
-
+		
 		strcpy (filter_opt_p->quality, opt);
 	}
 
@@ -332,6 +447,49 @@ get_option_for_ppd (const char *printer, filter_option_t *filter_opt_p)
 		strcpy (filter_opt_p->inputslot, opt);
 	}
 
+	/* brightness */
+	if (filter_opt_p->brightness[0] == '\0')
+	{
+		opt = get_default_choice (ppd_p, "Brightness");
+		if (!opt)
+		{
+			debug_msg("can not get brightness\n");
+			strcpy (filter_opt_p->brightness, "0");
+			
+		}
+		else
+		strcpy (filter_opt_p->brightness, opt);
+	}
+
+	/* contrast */
+	if (filter_opt_p->contrast[0] == '\0')
+	{
+		opt = get_default_choice (ppd_p, "Contrast");
+		if (!opt)
+		{
+			debug_msg("can not get contrast\n");
+			strcpy (filter_opt_p->contrast, "0");
+			
+		}
+		else
+		strcpy (filter_opt_p->contrast, opt);
+	}
+
+	/* saturation */
+	if (filter_opt_p->saturation[0] == '\0')
+	{
+		opt = get_default_choice (ppd_p, "Saturation");
+		if (!opt)
+		{
+			debug_msg("can not get saturation\n");
+			strcpy (filter_opt_p->saturation, "0");
+			
+		}
+		else
+		strcpy (filter_opt_p->saturation, opt);
+	}
+
+
 #ifdef INK_CHANGE_SYSTEM
 	/* inkset */
 	if (filter_opt_p->inkset[0] == '\0')
@@ -408,6 +566,14 @@ get_option_for_arg (const char *opt_str, filter_option_t *filter_opt_p)
 	if (opt)
 		strcpy (filter_opt_p->inputslot, opt);
 
+	opt = cupsGetOption ("Brightness", opt_num, option_p);
+	if (opt)
+		strcpy (filter_opt_p->brightness, opt);
+
+	opt = cupsGetOption ("Contrast", opt_num, option_p);
+	if (opt)
+		strcpy (filter_opt_p->contrast, opt);
+
 	return 0;
 }
 
